@@ -68,7 +68,7 @@ static void convert_USER_INFO_X_to_samr_user_info21(struct USER_INFO_X *infoX,
 		fields_present |= SAMR_FIELD_DESCRIPTION;
 	}
 	if (infoX->usriX_password_age) {
-		fields_present |= SAMR_FIELD_FORCE_PWD_CHANGE;
+		fields_present |= SAMR_FIELD_EXPIRED_FLAG;
 	}
 	if (infoX->usriX_full_name) {
 		fields_present |= SAMR_FIELD_FULL_NAME;
@@ -1201,9 +1201,6 @@ static NTSTATUS libnetapi_samr_lookup_user_map_USER_INFO(TALLOC_CTX *mem_ctx,
 	}
 
 	switch (level) {
-		case 0:
-			/* already returned above */
-			break;
 		case 1:
 			status = info21_to_USER_INFO_1(mem_ctx, info21, &info1);
 			NT_STATUS_NOT_OK_RETURN(status);
